=head1 NAME

CustomInspector - Used to inspect the demo window controls
when they get built

=cut





package CustomInspector;
use base qw( Win32::GUI::Loft::ControlInspector );





use strict;
use Data::Dumper;





=head1 PROPERTIES

=head1 METHODS

=head2 buildAdd($objContainer, $objControl)

This method gets called during the build process once for
each Custom control in the window.

Insert a new Win32::GUI object into $objContainer (which is
probably, but not certainly, a Win32::GUI::Window or
DialogBox). Not that you'll have to actually B<insert> the
control, so use AddXXXX or somesuch.

You may NOT change $objControl!

You may want to subclass this method if you want to use the
Custom control and add controls of your own. Use the "Name"
property to identify the control.

Return the newly created Win32::GUI object, or undef on
errors (in which case the the rest of the dialog will be
created as usual).

=cut
sub buildAdd { my $self = shift; my $pkg = ref($self);
	my ($objContainer, $objControl) = @_;

	#Use this to determine what kind of control you want
	#to add
	my $name = $objControl->prop("Name");

	if($name eq "btnCustom") {
		my $objNew = $objContainer->AddButton(
				-name => $name,
				-text => "But hey presto! This is a custom control!",
				-left => $objControl->prop("Left"),
				-top => $objControl->prop("Top"),
				-width => $objControl->prop("Width"),
				-height => $objControl->prop("Height"),
				);

		return($objNew);
		}

	#Other properties of the Custom control are:
	#Left, Top, Height, Width, Visible, Enable
	#That's all you get to play with.

	return(undef);
	}




1;





#EOF