=head1 NAME

FetchInspector - Used to inspect the Fetch window controls
when they get built

=cut





package FontInspector;
use base qw( Win32::GUI::Loft::ControlInspector );





use strict;
use Data::Dumper;





=head1 PROPERTIES

=head1 METHODS

=head2 buildOptions($oControl, $raOption)

This method gets called during the build process before the
creation of each control.

Return array of build options which in the unmodified case
is equivalent to returning @$aOption.

$raOption contains key, value pairs that will be passed on
to the AddXXXX method to create the object. Option names may
be present many times, so you may NOT treat it as a hash.

An example of a $raOption:

	[ "-name", "winMain", "-text", "Main window" ]

You may change the contents of $raOption. You may NOT change
$oControl!

This method is subclassed to change the font on controls 
that have the FontName property.

Return the array on success, else an empty array () in which
case the control will not be created.

=cut
my %hFont;		#Permanent the reference to the new font so it doesn't go out of scope.
sub buildOptions { my $self = shift; my $pkg = ref($self);
	my ($oControl, $raOption) = @_;

	my $fntLabel = Win32::GUI::Font->new(
				-size=>16,
				-bold=>0,
				-face=>"Verdana") or die;
				
	#Modify controls that have a FontName set
	my $font = $oControl->prop("FontName") || "";
	if($font ne "") {
		my $oFont = Win32::GUI::Font->new(
				-size => $oControl->prop("FontSize") || 16,
				-face => $font,
				-bold => 0,
				) or next;

		push(@$raOption, "-font" => $oFont);
		$hFont{$oFont} = $oFont;		#Permanent it
		}

	return(@$raOption);
	}





1;





#EOF